@@ -3,7 +3,7 @@ library(tsbox)
 
 context("ts_index")
 
-skip_on_appveyor()  # it works on my windows machine not clear what's wrong
+# skip_on_appveyor()  # it works on my windows machine not clear what's wrong
 skip_on_cran()
 
 test_that("ts_index series have same pc rates", {
